package betterquesting.api2.utils;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.questing.party.IParty;
import betterquesting.api2.cache.QuestCache;
import betterquesting.api2.storage.DBEntry;
import betterquesting.questing.party.PartyManager;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.TreeSet;
import java.util.UUID;
import javax.annotation.Nonnull;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.server.MinecraftServer;
import net.minecraftforge.common.util.FakePlayer;

/* loaded from: betterquesting_api2_utils.jar:betterquesting/api2/utils/ParticipantInfo.class */
public class ParticipantInfo {
    public final EntityPlayer PLAYER;
    public final UUID UUID;
    public final List<UUID> ALL_UUIDS;
    public final List<EntityPlayer> ACTIVE_PLAYERS;
    public final List<UUID> ACTIVE_UUIDS;
    public final DBEntry<IParty> PARTY_INSTANCE;

    public ParticipantInfo(@Nonnull EntityPlayer player) {
        this.PLAYER = player;
        this.UUID = QuestingAPI.getQuestingUUID(player);
        this.PARTY_INSTANCE = PartyManager.INSTANCE.getParty(this.UUID);
        MinecraftServer server = MinecraftServer.func_71276_C();
        if (this.PARTY_INSTANCE == null || server == null || (player instanceof FakePlayer)) {
            this.ACTIVE_PLAYERS = Collections.singletonList(player);
            this.ACTIVE_UUIDS = Collections.singletonList(this.UUID);
            this.ALL_UUIDS = Collections.singletonList(this.UUID);
            return;
        }
        List<EntityPlayer> actPl = new ArrayList<>();
        List<UUID> actID = new ArrayList<>();
        List<UUID> allID = new ArrayList<>();
        for (UUID mem : ((IParty) this.PARTY_INSTANCE.getValue()).getMembers()) {
            allID.add(mem);
            EntityPlayer pMem = null;
            for (Object o : server.func_71203_ab().field_72404_b) {
                if (((EntityPlayer) o).func_146103_bH().getId().equals(mem)) {
                    pMem = (EntityPlayer) o;
                }
            }
            if (pMem != null) {
                actPl.add(pMem);
                actID.add(mem);
            }
        }
        this.ACTIVE_PLAYERS = Collections.unmodifiableList(actPl);
        this.ACTIVE_UUIDS = Collections.unmodifiableList(actID);
        this.ALL_UUIDS = Collections.unmodifiableList(allID);
    }

    public void markDirty(@Nonnull List<Integer> questIDs) {
        QuestCache qc = this.PLAYER.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
        if (qc != null) {
            qc.getClass();
            questIDs.forEach((v1) -> {
                r1.markQuestDirty(v1);
            });
        }
    }

    public void markDirtyParty(@Nonnull List<Integer> questIDs) {
        if (this.ACTIVE_PLAYERS.size() <= 0 || questIDs.size() <= 0) {
            return;
        }
        this.ACTIVE_PLAYERS.forEach(value -> {
            QuestCache qc = value.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
            if (qc != null) {
                qc.getClass();
                questIDs.forEach((v1) -> {
                    r1.markQuestDirty(v1);
                });
            }
        });
    }

    @Nonnull
    public int[] getSharedQuests() {
        TreeSet<Integer> active = new TreeSet<>();
        this.ACTIVE_PLAYERS.forEach(p -> {
            QuestCache qc = p.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
            if (qc != null) {
                for (int value : qc.getActiveQuests()) {
                    active.add(Integer.valueOf(value));
                }
            }
        });
        int[] shared = new int[active.size()];
        int i = 0;
        Iterator<Integer> it = active.iterator();
        while (it.hasNext()) {
            int value = it.next().intValue();
            int i2 = i;
            i++;
            shared[i2] = value;
        }
        return shared;
    }
}
